@@ -1,14 +1,11 @@
 #!/bin/sh
 
-# Copyright (C) 2022 Internet Systems Consortium, Inc. ("ISC")
+# Copyright (C) 2022-2024 Internet Systems Consortium, Inc. ("ISC")
 #
 # This Source Code Form is subject to the terms of the Mozilla Public
 # License, v. 2.0. If a copy of the MPL was not distributed with this
 # file, You can obtain one at http://mozilla.org/MPL/2.0/.
 
-# shellcheck disable=SC1091
-# SC1091: Not following: ... was not specified as input (see shellcheck -x).
-
 # Exit with error if commands exit with non-zero and if undefined variables are
 # used.
 set -eu
@@ -17,12 +14,16 @@ set -eu
 # SC2034: ... appears unused. Verify use (or export if used externally).
 prefix="/usr"
 
-# Include utilities. Use installed version if available and
-# use build version if it isn't.
-if [ -e ${prefix}/share/kea/scripts/admin-utils.sh ]; then
-    . "${prefix}/share/kea/scripts/admin-utils.sh"
+# Include utilities based on location of this script. Check for sources first,
+# so that the unexpected situations with weird paths fall on the default
+# case of installed.
+script_path=$(cd "$(dirname "${0}")" && pwd)
+if test "${script_path}" = "/build/kea/src/kea-2.6.1/src/share/database/scripts/pgsql"; then
+    # shellcheck source=./src/bin/admin/admin-utils.sh.in
+    . "/build/kea/src/kea-2.6.1/src/bin/admin/admin-utils.sh"
 else
-    . "/build/kea/src/kea-2.2.0/src/bin/admin/admin-utils.sh"
+    # shellcheck source=./src/bin/admin/admin-utils.sh.in
+    . "${prefix}/share/kea/scripts/admin-utils.sh"
 fi
 
 VERSION=$(pgsql_version "$@")
@@ -36,7 +37,7 @@ fi
 psql "$@" >/dev/null <<EOF
 START TRANSACTION;
 
--- This line starts the schema upgrade to version 13.
+-- This line starts the schema upgrade to version 13.0.
 
 -- JSON functions --
 
@@ -673,7 +674,7 @@ CREATE UNIQUE INDEX key_dhcp6_identifier_subnet_id ON hosts
 UPDATE schema_version
     SET version = '13', minor = '0';
 
--- This line concludes the schema upgrade to version 13.
+-- This line concludes the schema upgrade to version 13.0.
 
 -- Commit the script transaction.
 COMMIT;
